aboutsummaryrefslogtreecommitdiff
path: root/engines/kyra/kyra_v1.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'engines/kyra/kyra_v1.cpp')
-rw-r--r--engines/kyra/kyra_v1.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/engines/kyra/kyra_v1.cpp b/engines/kyra/kyra_v1.cpp
index 92feec7608..3d24655a9b 100644
--- a/engines/kyra/kyra_v1.cpp
+++ b/engines/kyra/kyra_v1.cpp
@@ -120,7 +120,7 @@ Common::Error KyraEngine_v1::init() {
} else if (_flags.platform == Common::kPlatformAmiga) {
_sound = new SoundAmiga(this, _mixer);
} else if (midiDriver == MD_ADLIB) {
- _sound = new SoundAdlibPC(this, _mixer);
+ _sound = new SoundAdLibPC(this, _mixer);
} else {
Sound::kType type;
@@ -149,9 +149,9 @@ Common::Error KyraEngine_v1::init() {
// Unlike some SCUMM games, it's not that the MIDI sounds are
// missing. It's just that at least at the time of writing they
// are decidedly inferior to the Adlib ones.
if (ConfMan.getBool("multi_midi")) {
- SoundAdlibPC *adlib = new SoundAdlibPC(this, _mixer);
+ SoundAdLibPC *adlib = new SoundAdLibPC(this, _mixer);
assert(adlib);
_sound = new MixedSoundDriver(this, _mixer, soundMidiPc, adlib);
@@ -149,9 +149,9 @@ Common::Error KyraEngine_v1::init() {
// Unlike some SCUMM games, it's not that the MIDI sounds are
// missing. It's just that at least at the time of writing they
- // are decidedly inferior to the Adlib ones.
+ // are decidedly inferior to the AdLib ones.
if (ConfMan.getBool("multi_midi")) {